pub struct OnlineConfig {
pub duration: Option<u64>,
pub promiscuous: bool,
pub nb_rxd: usize,
pub mtu: usize,
pub hardware_assist: bool,
pub dpdk_supl_args: Vec<String>,
pub monitor: Option<MonitorConfig>,
pub ports: Vec<PortMap>,
}Expand description
Live traffic analysis options.
Online mode performs traffic analysis on a live network interface. Either OnlineConfig or OfflineConfig must be specified, but not both.
Example
[online]
duration = 30
nb_rxd = 32768
promiscuous = true
mtu = 1500
hardware_assist = true
dpdk_supl_args = []
[online.monitor.display]
throughput = true
mempool_usage = true
[online.monitor.log]
directory = "./log"
interval = 1000
[[online.ports]]
device = "0000:3b:00.0"
cores = [1,2,3,4]
[[online.ports]]
device = "0000:3b:00.1"
cores = [5,6,7,8]Fields
duration: Option<u64>If set, the applicaton will stop after duration seconds. Defaults to None.
promiscuous: boolWhether promiscuous mode is enabled for all ports. Defaults to true.
nb_rxd: usizeThe number of RX descriptors per receive queue. Defaults to 4096.
Receive queues are polled for packets using a run-to-completion model. Deeper queues will be more tolerant of processing delays at the cost of higher memory usage and hugepage reservation.
mtu: usizeMaximum transmission unit (in bytes) allowed for ingress packets. Defaults to 1500.
To capture jumbo frames, set this value higher (e.g., 9702).
hardware_assist: boolIf set, will attempt to offload parts of the filter to the NIC, depending on its hardware
filtering support. Defaults to true.
dpdk_supl_args: Vec<String>If set, will pass supplementary arguments to DPDK EAL (see DPDK
configuration). For instance --no-huge.
Defaults to empty string.
monitor: Option<MonitorConfig>Live performance monitoring. Defaults to None.
ports: Vec<PortMap>List of network interfaces to read from.